Idaho Supreme Court Civil Opinions | Supreme Court

Skip to main content

# STATE OF IDAHO JUDICIAL BRANCH
Supreme Court Appeals

## Search form

Search

## Idaho Supreme Court Civil Opinions

The Idaho Supreme Court and Idaho Court of Appeals cited opinions are made available online as a public service. All cited opinions are posted the day of their release. West Publishing Company publishes all cited opinions in the Pacific Reporter and Idaho Reports volumes. All cited opinions are removed from this site one-year upon release.

NOTICE: These opinions are subject to formal revision before publication in the preliminary print of the Pacific Reporter. Readers are requested to notify the Clerk of the Court/Reporter of Decisions, Supreme Court of Idaho, Boise, Idaho, 83720-0101, of any typographical or other formal errors, in order that corrections may be made before the preliminary print goes to press.

### By Release Date

- - *Video Archives are posted if and when available. For best results, use Internet Explorer.

    Release Date | Docket# | Case Name | Opinion Summary | Notes
    October 15, 2015 | 43074 | Greater Boise Auditorium District v. Frazier | - Opinion - Summary | Petition for Judicial Confirmation
    Sept 30, 2015 | 42216 | Sky Canyon Properties v. The Golf Club at Black Rock, LLC | - Opinion - Summary | Appeal from denial of attorney fees and costs on remand
    Sept 30, 2015 | 42125 | Martin Hayes v. City of Plummer | - Opinion - Summary | Premises liability claim
    Sept 25, 2015 | 41951 | Kennedy v. Hagadone Hospitality Co. | - Opinion - Summary | INDUSTRIAL COMMISSION
    Sept 25, 2015 | 42161 | Rice v. Sallaz | - Opinion - Summary | Breach of contract
    Sept 25, 2015 | 43152 | Jane Doe (2015-03) v. John Doe | - Opinion - Summary | Termination of parental rights (father)
    Sept 25, 2015 | 42018 | Idaho Transportation v. Ascorp, Inc. | - Opinion - Summary | Appeal from award of attorney fees
    Sept 25, 2015 | 41113 | Burlile v. Bd of Co Commissioners, Payette | - Opinion - Summary | Appeal from the approval of a conditional rezone
    Sept 25, 2015 | 41956 | City of Challis v. Consent of the Governed Caucus | - Opinion - Summary | SUBSTITUTE OPINION The City sought imporvements to their water distribution system incurring a debt without a public vote.
    Sept 25, 2015 | 42296 | Walco, Inc v. County of Idaho | - Opinion - Summary | Misappropriation of trade secrets
    Sept 25, 2015 | 42237 | Fairchild v. Kentucky Fried Chicken | - Opinion - Summary | INDUSTRIAL COMMISSION Worker's Compensation
    Sept 25, 2015 | 42417 | Perry Krinitt v. Dept of Fish and Game | - Opinion - Summary | Wrongful death
    Sept 10, 2015 | 43169 | Coeur d'Alene Tribe v. Lawerence Denney | - Opinion - Summary | The Tribe's Writ of Mandamus Re: Senate Bill 1011.
    Sept 4, 2015 | 42243 | St. Alphonsus RMC v. Gooding County | - Opinion - Summary | Third-party medical indigency.
    Aug 27, 2015 | 42189 | DOE(s) v. Boy Scouts of America | - Opinion - Summary | Certification re Questions of Law. (Constructive fraud claims)
    Aug 24, 2015 | 42112 | Eric Kawamura v. Jessica Kawamura | - Opinion - Summary | Divorce. Nature of property.
    Aug 20, 2015 | 40625 | American Bank v. BRN Dev. & Taylor Eng. | - Opinion - Summary | Foreclosure action and cross-claim asserting negligence.
    July 23, 2015 | 42173 | Michelle Campbell v. Parkway Surgery | - Opinion - Summary | Breach of contract.
    July 23, 2015 | 41679 | State v. Philip Morris, R.J. Reynolds | - Opinion - Summary | SUBSTITUTE OPINION. State appeals settlement award. (RE: 1998 Tobacco Master Settlement Agreement.)
    July 22, 2015 | 41898 | Monica Garner v. Christopher Garner | - Opinion - Summary | Child support.
    July 17, 2015 | 42614 | Safaris Unlimited v. Mike Von Jones | - Opinion - Summary | Appeal from grant of summary judgment in favor of Safaris' claims for breach of contract.
    July 16, 2015 | 41742 | Colafranceschi v. Briley & Robinson | - Opinion - Summary | Defamation and professional malpractice.
    July 16, 2015 | 41451 | Stilwyn, Inc. v. Rokan Corporation | - Opinion - Summary | Claims for relief from failed transaction.
    July 16, 2015 | 42384 | Jackson Hop v. Farm Bureau Insurance | - Opinion - Summary | Appeal from ruling that insured was not entitled to prejudgment interest.
    July 14, 2015 | 41397-41398 | Podsaid v. Outfitters & Guides Licensing | - Opinion - Summary | Appeals arising from termination of guide license.
    July 13, 2015 | 42092 | La Bella Vita v. Amanda Shuler | - Opinion - Summary | Misappropriation of trade secrets.
    July 7, 2015 | 42589 | Sohar Chavez v. Kevin Stokes | - Opinion - Summary | INDUSTRIAL COMMISSION. Life Flight costs in work related injury case.
    June 30, 2015 | 42372 | John Doe v. State Sex Offender Registry | - Opinion - Summary | Appeal from dismissal of Verified Petition for Declaratory Judgment.
    June 24, 2015 | 42821 | Termination of Parental Rights of John Doe (2015-01) | - Opinion - Summary | Termination of father's righs.
    June 23, 2015 | 41868 | Tracfone Wireless v. State of Idaho | - Opinion - Summary | RE: Fees
    June 23, 2015 | 42165 | Judy Charney v. Dennis Charney | - Opinion - Summary | Appeal from award of attorney fees.
    June 22, 2015 | 42192 | Virgil Adams v. Kimberley One Townhouse | - Opinion - Summary | From an amended HOA Declaration restricting renting out a unit.
    June 22, 2015 | 41825 | Federal National Mortgage v. Hafer | - Opinion - Summary | Foreclosure.
    June 22, 2015 | 42521 | Todd L. Hamilton v. Alpha Services, LLC | - Opinion - Summary | INDUSTRIAL COMMISSION - Worker's compensation, death benefits.
    June 22, 2015 | 41972 | Pines, D.O. v. State Board of Medicine | - Opinion - Summary | Appeal from disciplinary order.
    May 28, 2015 | 42675 | Termination of Parental Rights of John Doe (2014-25) | - Opinion - Summary | Father's appeal from magistrate judgment terminating parental rights and allowing adoption.
    May 22, 2015 | 42175 | St. Al's RMC v. Elmore County | - Opinion - Summary | Appeal from denial of applications for medical indigency
    May 21, 2015 | 42053 | Melene James v. City of Boise | - Opinion - Summary | Claim for damages resulting in police dog bite
    May 21, 2015 | 42093 | James Hilliard v. Murphy Land Company | - Opinion - Summary | Admissibility of affidavits during summary judgment proceedings.
    May 21, 2015 | 41178 | Christina J. Greenfield v. Eric J. Wurmlinger | - Opinion - Summary | One neighbor's complaints against another for claims of violations of the CC&R and City Code.
    May 21, 2015 | 41615 | Gary Holdaway v. Broulim's Supermarket | - Opinion - Summary | Suit for personal injury
    April 23, 2015 | 42700 | Dept of H&W v. John Doe (2014-26) | - Opinion - Summary | RE: Termination of Parental Rights
    April 23, 2015 | 42220 | Gina Poledna v. Dept of Labor | - Opinion - Summary | INDUSTRIAL COMMISSION - Denial of Unemployment benefits
    April 21, 2015 | 42588 | Krissy M. Lamont v. Matthew J. Lamont | - Opinion - Summary | Expedited permissive appeal - child custody dispute
    April 7, 2015 | 41524 | Cherri Lynn Nix v. Elmore County | - Opinion - Summary | Appeal from termination of employment
    April 1, 2015 | 41583 | Daryl K. and Linda L. Mullinix v. Killgore's Salmon River Fruit Co. | - Opinion - Summary | Right to use pipeline to convey water
    April 1, 2015 | 42141 | Hilary Beth Candland Firmage v. Howard Hunter Snow | - Opinion - Summary | Modification of Child Custody Arrangement
    March 30, 2015 | 41286 | Dennis Ray Hennefer v. Blaine County School District #61 | - Opinion - Summary | School District Tort Liability
    March 5, 2015 | 41683 | Cedillo v. Farmers Insurance Co of Idaho | - Opinion - Summary | SUBSTITUTE OPINION: Underinsured motorist
    March 2, 2015 | 41265 | Big Wood Ranch v. Water Users' Association of the Broadford Slough and Rockwell Bypass Lateral Ditches, Inc. | - Opinion - Summary | Collection of assessments for maintenance
    Feb 27, 2015 | 41467 | LuAnn Shubert v. Macy's West, Inc. | - Opinion - Summary | INDUSTRIAL COMMISSION Worker's Compensation / Disability Benefits
    Feb 26, 2015 | 41668 | Jayo Development, Inc. v. Ada County Bd. of Equalization | - Opinion - Summary | Property tax exemption
    Feb 26, 2015 | 42141 | Hilary Firmage v. Howard Snow | - Opinion - Summary | Modification of child custody
    Feb 26, 2015 | 41600 | Thomas Arnold v. City of Stanley | - Opinion - Summary | Open meeting law
    Feb 26, 2015 | 41454 | Nampa Education Association v. Nampa School District No. 131 | - Opinion - Summary | An addenda to the teachers' employment contracts were illegal and unenforceable.
    Feb 26, 2015 | 41846 | Marjorie Ellmaker v. Calvin Tabor | - Opinion - Summary | Promissory note (inherited)
    Feb 26, 2015 | 41452 | Duane R. Mueller v. Carolyn Hill | - Opinion - Summary | Damages for common law trespass and attorney fees for statutory trespass.
    Feb 26, 2015 | 41316 | No. Idaho Bldg Contractors Assoc. v. City of Hayden | - Opinion - Summary | Sewer connection fee
    Feb 11, 2015 | 40168 | Dept of Transportation v. HJ Grathol | - Opinion - Summary | Eminent domain. Appeal from judgment in just compensation from ITD.
    Feb 10, 2015 | 41214 | 917 LUSK, LLC v. City of Boise | - Opinion - Summary | Appeal from City Council's decision granting a conditional use permit
    Feb 6, 2015 | 41745 | Dalrie Cook v. Hugo Marcelo Arias | - Order | Order Denying Reconsideration and Vacating Judgment
    Feb 4, 2015 | 41501 | Alan Golub v. Kirk-Hughes Development | - Opinion - Summary | Appeal from grant of Golub's summary judgment finding their lien had priority
    Feb 2, 2015 | 40474 | Keith A. Sims v. Dan S. Jacobson | - Opinion - Summary | Appeal from grant of attorney fees
    Jan 30, 2015 | 41505 | Alan Golub v. Kirk-Scott, LTD | - Opinion - Summary | Two creditors dispute whose claim against debtor's property has priority
    Jan 26, 2015 | 42442 | Dept of H&W v. Jane Doe (2014-22) | - Opinion - Summary | RE: Termination of Parental Rights
    Jan 26, 2015 | 41338 | Mosell Equities, LLC v. Berryhill & Co, Inc | - Opinion - Summary | Appeal from order granting new trial
    Jan 23, 2015 | 42529 | Dept of H&W v. Jane Doe (2014-23) | - Opinion - Summary | RE: Termination of Parental Rights
    Jan 23, 2015 | 41448 | Plane Family Trust v. Skinner | - Opinion - Summary | Appeal from decision denying a motion to void a portion of a stipulated judgment
    Jan 23, 2015 | 41584 | Flying "A" Ranch v. County Commissioners of Fremont County | - Opinion - Summary | Appeal from the district court's determination to vacate the Boards designation of a county road
    Jan 23, 2015 | 41991 | Thrall v. St. Luke's Regional Med Cntr | - Opinion - Summary | INDUSTRIAL COMMISSION - Unemployment Benefits
    Jan 23, 2015 | 41523 | Boyd-Davis v. Macomber Law, PLLC | - Opinion - Summary | INDUSTRIAL COMMISSION - Unemployment Benefits
    Jan 21, 2015 | 41269 | ACI Northwest, Inc. v. Monument Heights, LLC | - Opinion - Summary | Foreclosure of mechanic's liens on property encumbered by deeds of trust.
    Jan 09, 2015 | 41663 | Minnick v. Hawley Troxell Ennis & Hawley, LLP and Geoffrey M. Wardle | - Opinion - Summary | Professional malpractice
    Dec 30, 2014 | 41297 | Int'l Real Estate Solutions, Inc. v. Arave | - Opinion - Summary | Appeal from decision to dismiss motion to compel the filing of a satisfaction of judgment
    Dec 18, 2014 | 41605 | Bill Gailey v. Kim Whiting | - Opinion - Summary | Professional negligence
    Dec 18, 2014 | 41589 | Pocatello Hospital v. Quail Ridge Medical Investor | - Opinion - Summary | Ground lease
    Dec 18, 2014 | 41592 | Charles Bell v. IDOL and Sears | - Opinion - Summary | Unemployment benefits
    Dec 18, 2014 | 41485 | Re: Guardianship: Bond v. Round | - Opinion - Summary | Re: Visitation and attorney fees
    Dec 18, 2014 | 40848 | Brent Regan v. Jeff Owen | - Opinion - Summary | Whether Owen's deed should be reformed to grant easment
    Dec 18, 2014 | 42234 | H&W v. John Doe (2014-15) | - Opinion - Summary | Termination of parental rights
    Dec 15, 2014 | 42291 | H&W v. Jane Doe (2014-17) | - Opinion - Summary | Termination of parental rights
    Dec 12, 2014 | 40615 | H&W v. Cathie Peterson RE: The Estate of Melvin Peterson (deceased) | - Opinion - Summary | SUBSTITUTE OPINION - The Opinion of August 13, 2014 is withdrawn. RE: Medicaid benefits
    Dec 8, 2014 | 41277 | H.F.L.P., LLC v. City of Twin Falls | - Opinion - Summary | Easment
    Dec 2, 2014 | 41013 | Stephanie Reed v. Scott Reed | - Opinion - Summary | Divorce
    Dec 2, 2014 | 40438 | Terri Boyd-Davis v. Timothy Baker | - Opinion - Summary | Real property boundary dispute
    Nov 28, 2014 | 41593 | Trudy Deon v. H & J, Inc. | - Opinion - Summary | Industrial Commission - Worker Compensation
    Nov 28, 2014 | 41560 | Mercedes E. Turner v. City of Lapwai | - Opinion - Summary | Unpaid compensation and reimbursement for expenses during employment
    Nov 28, 2014 | 41041 | Franklin Building Supply v. Aaron Hymas | - Opinion - Summary | Construction liability
    Nov 28, 2014 | 41469 | Newman K. Giles v. Eagle Farms, Inc. | - Opinion - Summary | Industrial Commission - Income Benefits
    Nov 25, 2014 | 40587 | Christian Westby, et al v. Schaefer, M.D. | - Opinion - Summary | Appeal from district court's denial of motion to reconsider a protective order
    Nov 13, 2014 | 41976 | Emily E. Suter v. Jeffrey C. Biggers | - Opinion - Summary | Custody dispute
    Nov 13, 2014 | 40514 | Stanley Consultants v. Integrated Financial Associates | - Opinion - Summary | This appeal involves several cases with common claims for nonpayment against a developer
    Nov 6, 2014 | 41209 | Su Warren v. Williams & Parsons | - Opinion - Summary | Industrial Commission - Worker's Compensation
    Oct 29, 2014 | 41193 | Timothy Williams v. Idaho State Board of Real Estate Appraisers | - Opinion - Summary | Disciplinary proceedings for professional misconduct
    Oct 29, 2014 | 40762 | Gene L. Mattox v. Life Care Centers of America | - Opinion - Summary | Medical Malpractice
    Oct 29, 2014 | 41421 | Samuel J. Zylstra v. Boise State University | - Opinion - Summary | Negligence
    Oct 29, 2014 | 41188 | Federal Home Loan Mortgage Corp. v. Margaret A. Butcher | - Opinion - Summary | Foreclosure
    Oct 29, 2014 | 41252 | U.S. Bank National Association N.D. v. Citimortgage, Inc. | - Opinion - Summary | Lien priority dispute
    Oct 29, 2014 | 41296 | Richard J. Braese, Jr. v. Stinker Stores, Inc. | - Opinion - Summary | Claim for injuries
    Oct 29, 2014 | 41305 | Cable One, Inc. v. Idaho State Tax Commission | - Opinion - Summary | Income earned by multistate corporation was taxable.
    Oct 29, 2014 | 40427 | Vianna Stibal v. April Fano | - Opinion - Summary | Breach of Release Agreement
    Oct 29, 2014 | 40865 | Spirit Ridge Mineral Springs v. Franklin County | - Opinion - Summary | Request for abatement of a private nuisance and injunction against a gun range
    Sept 26, 2014 | 40883 | Brad C. Carr v. Crystal (Pridgen) Edgar | - Opinion - Summary | Child custody dispute
    Sept 24, 2014 | 40749 | Kevin D. Hope v. Industrial Special Indemnity Fund | - Opinion - Summary | Worker's Compensation
    Sept 19, 2014 | 41301 | Jeremy J. Gugino v. Dennis J. Sallaz | - Opinion - Summary | Collateral attack on divorce decree.
    Sept 19, 2014 | 41889 | Jay Brown v. Auga Greenheart | - Opinion - Summary | An action for the reformation of a deed to real property.
    Sept 19, 2014 | 41446 | Tracy Sales v. Stacie Peabody | - Opinion - Summary | Suit against Day Spa claiming infection resulting from pedicure.
    Sept 19, 2014 | 41256 | Idaho Youth Ranch v. Ada County Bd of Equalization | - Opinion - Summary | Denial of application for property tax exemption.
    Sept 19, 2014 | 40887 | Scott Bybee v. Patrick D. Gorman, M.D. | - Opinion - Summary | Medical Malpractice claim
    Sept 19, 2014 | 40793 | Steven B. Cummings v. Roger L. Stephens and Northern Title Co of Idaho | - Opinion - Summary | This is a cross-appeal from judgments wherein the buyer was denied damages against the seller and awarded judgment against the title company.
    Aug 28, 2014 | 40581 | Frontier Development Grp v. Caravella | - Opinion - Summary | Breach of residential construction agreement.
    Aug 25, 2014 | 41012 | Corgatelli v. Steel West, Inc. | - Opinion - Summary | Industrial Commission - Award of credit for benefits paid
    Aug 22, 2014 | 40742 | Ryan Conner v. Bryan F. Hodges, M.D. | - Opinion - Summary | Medical malpractice
    Aug 22, 2014 | 40970 | Serrano v. Four Seasons Framing | - Opinion - Summary | Industrial Commission - Accident injury
    Aug 22, 2014 | 42020 | Termination of Parental Rights (Father) | - Opinion - Summary | Father's Rights
    Aug 22, 2014 | 40595-40599 | Taylor v. Riley / Taylor v. Cummings | - Opinion - Summary | ** SECOND ** AMENDED 8/27/14 Permissive appeal out of Ada Co. re: ruling by the district court that two attorneys who signed an opinion letter on behalf of a corporation affirming the validity of a stock redemption agreement could be liable to the person whose stock was redeemed when that redemption was later held unlawful.
    Aug 21, 2014 | 40966 | MRS v. Bonneville Billing and Collections | - Opinion - Summary | Substitute Opinion. Garnishment
    Aug 18, 2014 | 40340 | Agrisource, Inc v. Johnson | - Opinion - Summary | Breach of Contract Claim
    Aug 15, 2014 | 40375 | Camp Easton Forever, Inc v. Inland NW Council Boy Scouts of Amierica | - Opinion - Summary | Unambiguous deed
    Aug 6, 2014 | 41306 | Gregory Hull v. Richard Giesler | - Opinion - Summary | Contract rights
    Aug 6, 2014 | 40573 | ABC Agra v. Critical Access Group | - Opinion - Summary | Real property use restriction
    Aug 4, 2014 | 40974-40975 | SRBA: A&B Irrigation v. State of Idaho | - Opinion - Summary | Storage Water Rights
    Aug 4, 2014 | 40012 | St. Als v. MRI Associates | - Opinion - Summary | Substitute Opinion - Breach of Contract
    Aug 4, 2014 | 40232 | Billy J. Bringman v. New Albertsons, Inc. | - Opinion - Summary | Unemployment benefits
    Aug 1, 2014 | 41688 | Health & Welfare v. John Doe (13-29) | - Opinion - Summary | Parental Rights
    Aug 1, 2014 | 41023 | J&M Cattle Co v. Farmers National Bank | - Opinion - Summary | Security interest in agister's lien
    Aug 1, 2014 | 38793 | Mark Van v. Portneuf Medical Center | - Opinion - Summary | Whistleblower Act
    Aug 1, 2014 | 40566 | Pocatello Hospital v. Quail Ridge Medical Investor | - Opinion - Summary | Ground Lease
    Aug 1, 2014 | 41234 | Chance Lebow v. Commercial Tire | - Opinion - Summary | Industrial Commission - Unemployment Benefits
    July 31, 2014 | 41100 | Lynn Urrutia v. Ty (Cliff) Harrison | - Opinion - Summary | Foreclosure; Attorney Fees
    July 31, 2014 | 40738 | DAFCO v. Stewart Title Guaranty Co | - Opinion - Summary | Deed of Trust
    July 31, 2014 | 40992 | NW Farm Credit Svcs v. Lake Cascade Airpark | - Opinion - Summary | Deficiency Judgment
    July 8, 2014 | 39964 | Profits Plus Capital Mgmt. v. Jeffrey Podesta and Street Search | - Opinion - Summary | Breach of Contract
    June 24, 2014 | 40563 | Irina N. Shea v. Kevic Corporation | - Opinion - Summary |
    June 24, 2014 | 41681 | Re: Termination of Parental Rights (Father) | - Opinion - Summary |
    June 20, 2014 | 41208 | Talbot v. Desert View Care Center | - Opinion - Summary |
    June 18, 2014 | 40212 | April Beguesse, Inc. v. Kenneth Rammell | - Opinion - Summary |
    June 18, 2014 | 40124 | Wandering Trails v. Big Bite Excavation | - Opinion - Summary |
    June 17, 2014 | 39909 | Idaho Military HS v. Holbrook Baslen | - Opinion - Summary |
    June 17, 2014 | 40436 | Shinn v. Bd. of Co. Comm. Clearwater Co. | - Opinion - Summary |
    June 17, 2014 | 39685 | John Block v. City of Lewiston | - Opinion - Summary |
    June 17, 2014 | 40504 | Karrin Massey v. Conagra Foods | - Opinion - Summary |
    June 17, 2014 | 40939 | Tina Venable v. Internet Auto | - Opinion - Summary |
    June 17, 2014 | 40368 | Joseph Pierce v. Steve McMullen | - Opinion - Summary |
    June 17, 2014 | 40882 | Idaho Power v. New Energy Two & IPUC | - Opinion - Summary |
    June 17, 2014 | 40559 | Muchow v. Varsity Contractors, Inc. | - Opinion - Summary |
    June 17, 2014 | 40987 & 41132 | Karl H. Lewies v. Fremont County | - Opinion - Summary |
    June 17, 2014 | 41157 | Bank of Idaho v. First American Title | - Opinion - Summary |
    Apr 8, 2014 | 40672 | Terrie H. Rowley | - Opinion - Summary |
    Apr 7, 2014 | 40013 | Sanders v. Bd. of Trustees - Mt. Home School Dist. 193 | - Opinion - Summary |
    Mar 27, 2014 | 39774 | Janice Blizzard v. Lundeby, M.D. | - Opinion - Summary |
    Mar 19, 2014 | 40234 | Credit Suisse v. Teufel Nursery | - Opinion - Summary |
    Mar 19, 2014 | 40170 | Marvin F. Morgan v. Michael A. Demos, M.D. | - Opinion - Summary |
    Mar 19, 2014 | 40463 | Edged In Stone v. NW Power Systems | - Opinion - Summary |
    Mar 19, 2014 | 40578 | Marco Fonseca v. Corral Ag., Inc. | - Opinion - Summary |
    Mar 19, 2014 | 40827 | MRS v. Strawn; Lewis and Knight | - Opinion - Summary |
    Mar 18, 2014 | 41213 | Re: Termination of Parental Rights (Mother) | - Opinion - Summary |
    Mar 18, 2014 | 40142 | Jamee Lee Wade v. Bryan F. Taylor | - Opinion - Summary |
    Mar 18, 2014 | 41017-2013 | Debra Peterson v. Dept of H&W - Child Support | - Opinion - Summary |
    Mar 18, 2014 | 39556-2012 | William J. Waters v. All Phase Const. | - Opinion - Summary |
    Mar 18, 2014 | 40262 | Karen White v. Valley County | - Opinion - Summary |
    Mar 13, 2014 | 39624 | Morgan v. New Sweden Irrigation | - Opinion - Summary |
    Feb 20, 2014 | 38705 | McVicars v. Christensen | - Opinion - Summary |
    Feb 18, 2014 | 38823-2011 | Judy Nield v. Pocatello Health Services | - Opinion - Summary |
    Feb 11, 2014 | 40462 | Western Home Transport v. Dept. of Labor | - Opinion - Summary |
    Feb 11, 2014 | 40809 | Clearwater REI v. Mark Boling | - Opinion - Summary |
    Feb 11, 2014 | 40516 | Cuevas v. Barraza | - Opinion - Summary |
    Feb 10, 2014 | 39991 | Mulford v. Union Pacific Railroad | - Opinion - Summary |
    Feb 10, 2014 | 40369 | State v. John Doe (2012-10) | - Opinion - Summary |
    Feb 10, 2014 | 40002 | CUMIS Insurance v. Wade Massey | - Opinion - Summary |
    Feb 10, 2014 | 41463 | In the Matter of Adoption | - Opinion - Summary |
    Feb 10, 2014 | 40502 | Teurlings v. Larson | - Opinion - Summary |
    Feb 7, 2014 | 39708 | Guzman v. Piercy / Canyon Couny / Sutton | - Opinion - Summary |
    Feb 7, 2014 | 39160 | Johnson v. Highway 101 Investments, LLC | - Opinion - Summary |
    Feb 7, 2014 | 39757 | Melaleuca, Inc. v. Foeller | - Opinion - Summary |
    Feb 7, 2014 | 40084/ 40106 | Ada County v. Garden City / Meridian | - Opinion - Summary |
    Feb 7, 2014 | 40660 | Michael Vawter v. UPS, Inc. | - Opinion - Summary |
    Feb 7, 2014 | 39493 | Dennis Akers v. D.L. White | - Opinion - Summary |
    Feb 7, 2014 | 39182 | Dennis Akers v. Marti Mortensen | - Opinion - Summary |
    Feb 7, 2014 | 41233 | RE: Termination of Parental Rights | - Opinion - Summary |
    Jan 24, 2014 | 40101 | Farmers Nat'l. Bank v. Green River Dairy | - Opinion - Summary |
    Jan 3, 2014 | 40568 | Verdene Page v. McCain Foods, Inc. | - Opinion - Summary |
    Dec 30, 2013 | 39650 | Campbell v. Kvamme | - Opinion - Summary |
    Dec 20, 2013 | 40230 | American West Ent. v. CNH, LLC | - Opinion - Summary |
    Dec 18, 2013 | 39975 | Rita Turner v. Robert Turner | - Opinion - Summary |
    Dec 18, 2013 | 40344-2012 | Rule Steel Tanks, Inc. v. Dept. of Labor | - Opinion - Summary |
    Dec 18, 2013 | 41387-2013 | Jane Doe (13-23) v. John Doe | - Opinion - Summary |
    Dec 18, 2013 | 40512-2012 | Gregory Renshaw v. MERS | - Opinion - Summary |
    Dec 18, 2013 | 39151-2011 | Idaho Power v. Grouse Creek | - Opinion - Summary | Press Release
    Dec 17, 2013 | 38191/ 38192/ 38193 | A&B Irrigation v. ID Dept. of Water Resources | - Opinion - Summary |
    Dec 17, 2013 | 39942 | Bremer v. E. Greenacres Irrig. Dist. | - Opinion - Summary |
    Dec 13, 2013 | 39788 | John M. Hoch v. Robb Vance | - Opinion - Summary |
    Dec 11, 2013 | 39319 | Beers v. President - Church of Jesus Christ of LDS | - Opinion - Summary |
    Dec 6, 2013 | 39346 | Robby Mowrey v. Chevron Pipeline Co. | - Opinion - Summary |
    Dec 4, 2013 | 39690 | BV Beverage Company v. Idaho ABC | - Opinion - Summary |
    Nov 27, 2013 | 39409 | Silicon Int'l. v. Monsanto Co. | - Opinion - Summary |
    Nov 27, 2013 | 40087 | Geff Stringer v. William Robinson | - Opinion - Summary |
    Nov 27, 2013 | 39945 | Frogley v. Meridian Joint School Dist. 2 | - Opinion - Summary |
    Nov 27, 2013 | 39822 | Jeffry Black v. Idaho State Police | - Opinion - Summary |
    Nov 27, 2013 | 40393 | Dallas Clark v. Shari's Management Corp | - Opinion - Summary |
    Nov 26, 2013 | 39364 | Trevor Taft v. Jumbo Foods, Inc., | - Opinion - Summary |
    Nov 26, 2013 | 40061 | Norman Riley v. Spiral Butte Development, LLC | - Opinion - Summary |
    Nov 26, 2013 | 39957 | Liberty Northwest Ins. Co., v. Spudnick Equip. Co. | - Opinion - Summary |
    Nov 26, 2013 | 39033/ 39034 / 39035/ 39036 | State v. Keithly | - Opinion - Summary |
    Nov 26, 2013 | 39077/ 39078/ 39079 | Christopher Hopper v. Joseph and Bette Hopper | - Opinion - Summary |
    Nov 26, 2013 | 41149 | John Doe v. Jame Doe (2013-14) | - Opinion - Summary |
    Nov 26, 2014 | 39831 | Sky Canyon Properties v. The Golf Club at Black Rock | - Opinion - Summary |
    Nov 26, 2013 | 39445-2011 | Robert Siegwarth v. Opportunity Management Co. | - Opinion - Summary |
    Nov 26, 2013 | 39878-2012 | Holli Telfore v. Smith County | - Opinion - Summary |

- Printer-friendly version
- PDF version